@@ -10,7 +10,7 @@ pub(crate) fn multiply_alpha_avx2(
     mut dst_image: TypedImageViewMut<U8x4>,
 ) {
     let width = src_image.width().get() as usize;
-    let src_rows = src_image.iter_rows(0, src_image.height().get());
+    let src_rows = src_image.iter_rows(0);
     let dst_rows = dst_image.iter_rows_mut();
 
     for (src_row, dst_row) in src_rows.zip(dst_rows) {
@@ -32,7 +32,7 @@ pub(crate) fn multiply_alpha_inplace_avx2(mut image: TypedImageViewMut<U8x4>) {
 
 /// https://github.com/Wizermil/premultiply_alpha/blob/master/premultiply_alpha/premultiply_alpha.hpp#L232
 #[target_feature(enable = "avx2")]
-unsafe fn multiply_alpha_row_avx2(src_row: &[u32], dst_row: &mut [u32], width: usize) {
+unsafe fn multiply_alpha_row_avx2(src_row: &[U8x4], dst_row: &mut [U8x4], width: usize) {
     let mask_alpha_color_odd_255 = _mm256_set1_epi32(0xff000000u32 as i32);
     let div_255 = _mm256_set1_epi16(0x8081u16 as i16);
     #[rustfmt::skip]
